@@ -3,6 +3,7 @@
     SPDX-FileCopyrightText: 2007-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-FileCopyrightText: 2011 Luis Ángel Fernández Fernández <laffdez@gmail.com>
     SPDX-FileCopyrightText: 2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2022 Dmitrii Fomchenkov <fomchenkovda@basealt.ru>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -48,10 +49,10 @@
 #include "transactions/kgpgsignkey.h"
 #include "transactions/kgpgsignuid.h"
 #include "transactions/kgpgtransactionjob.h"
+#include "transactions/customstyleditemdelegate.h"
 
 #include <algorithm>
-#include <akonadi-contact_version.h>
-#if AKONADICONTACT_VERSION > QT_VERSION_CHECK(5, 19, 40)
+#ifndef HAS_AKONADI_CONTACT_SUBDIR
 #include <Akonadi/ContactEditor>
 #include <Akonadi/ContactEditorDialog>
 #include <Akonadi/ContactSearchJob>
@@ -329,6 +330,7 @@ KeysManager::KeysManager(QWidget *parent)
 	connect(this, &KeysManager::readAgainOptions, iproxy, &KeyListProxyModel::settingsChanged);
 
 	iview = new KeyTreeView(this, iproxy);
+	iview->setItemDelegate(new CustomStyledItemDelegate(iview));
 	connect(iview, &KeyTreeView::doubleClicked, this, QOverload<const QModelIndex &>::of(&KeysManager::defaultAction));
 	connect(iview, &KeyTreeView::importDrop, this, QOverload<const QList<QUrl> &>::of(&KeysManager::slotImport));
 	iview->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -483,10 +485,6 @@ KeysManager::KeysManager(QWidget *parent)
 	QMetaObject::invokeMethod(this, "refreshkey", Qt::QueuedConnection);
 }
 
-KeysManager::~KeysManager()
-{
-}
-
 void KeysManager::slotGenerateKey()
 {
 	if (m_genkey) {
@@ -2179,19 +2177,16 @@ void KeysManager::delsignkey()
 	if (nd == nullptr)
 		return;
 
-	QString uid;
 	QString parentKey;
 
 	KGpgExpandableNode *parent = nd->getParentKeyNode();
 	switch (parent->getType()) {
 	case ITYPE_PAIR:
 	case ITYPE_PUBLIC:
-		uid = QLatin1Char( '1' );
 		parentKey = parent->getId();
 		break;
 	case ITYPE_UID:
 	case ITYPE_UAT:
-		uid = parent->getId();
 		parentKey = parent->getParentKeyNode()->getId();
 		break;
 	default:
